about summary refs log tree commit diff
path: root/ops
diff options
context:
space:
mode:
Diffstat (limited to 'ops')
-rw-r--r--ops/nixos/monorepo-gerrit.nix20
1 files changed, 10 insertions, 10 deletions
diff --git a/ops/nixos/monorepo-gerrit.nix b/ops/nixos/monorepo-gerrit.nix
index eda64766f4..327ff633cb 100644
--- a/ops/nixos/monorepo-gerrit.nix
+++ b/ops/nixos/monorepo-gerrit.nix
@@ -53,18 +53,18 @@ in {
         "pull"
       ];
 
       # Configure for Sourcegraph.
       gitweb = {
         type = "custom";
-        url = "https://cs.tvl.fyi";
-        linkname = "Sourcegraph";
-        project = "/depot";
-        revision = "/depot/-/commit/\${commit}";
-        branch = "/depot@\${branch}";
-        tag = "/depot@\${tag}";
-        roottree = "/depot@\${commit}";
-        file = "/depot@\${commit}/-/blob/\${file}";
-        filehistory = "/depot@\${commit}/-/blob/\${file}#&tab=history";
+        url = "https://code.tvl.fyi";
+        project = "/";
+        revision = "/commit/?id=\${commit}";
+        branch = "/log/?h=\${branch}";
+        tag = "/tag/?h=\${tag}";
+        roottree = "/tree/?h=\${commit}";
+        file = "/tree/\${file}?h=\${commit}";
+        filehistory = "/log/\${file}?h=\${branch}";
+        linkname = "cgit";
       };
 
       # Auto-link panettone bug links
@@ -53,18 +53,18 @@ in {
       ];
 
-      # Configure for Sourcegraph.
+      # Configure for cgit.
       gitweb = {
         type = "custom";